@@ -1,5 +1,5 @@
 #
-# $Id: Escape.pm,v 3.26 2004/04/13 15:17:27 gisle Exp $
+# $Id: Escape.pm,v 3.28 2004/11/05 13:58:31 gisle Exp $
 #
 
 package URI::Escape;
@@ -92,6 +92,13 @@ will be the same as:
 
 but will even work for perl-5.6 for chars in the 128 .. 255 range.
 
+Note: Javascript has a function called escape() that produce the
+sequence "%uXXXX" for chars in the 256 .. 65535 range.  This function
+has really nothing to do with URI escaping but some folks got confused
+since it "does the right thing" in the 0 .. 255 range.  Because of
+this you sometimes see "URIs" with these kind of escapes.  The
+JavaScript encodeURI() function is similar to uri_escape_utf8().
+
 =item uri_unescape($string,...)
 
 Returns a string with each %XX sequence replaced with the actual byte
@@ -142,7 +149,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(uri_escape uri_unescape);
 @EXPORT_OK = qw(%escapes uri_escape_utf8);
-$VERSION = sprintf("%d.%02d", q$Revision: 3.26 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 3.28 $ =~ /(\d+)\.(\d+)/);
 
 use Carp ();
 
@@ -179,14 +186,15 @@ sub _fail_hi {
 
 sub uri_escape_utf8
 {
+    my $text = shift;
     if ($] < 5.008) {
-	my $text = shift;
 	$text =~ s/([^\0-\x7F])/do {my $o = ord($1); sprintf("%c%c", 0xc0 | ($o >> 6), 0x80 | ($o & 0x3f)) }/ge;
-	return uri_escape($text, @_);
+    }
+    else {
+	utf8::encode($text);
     }
 
-    require Encode;
-    return uri_escape(Encode::encode_utf8(shift), @_);
+    return uri_escape($text, @_);
 }
 
 sub uri_unescape
